@@ -27,9 +27,7 @@ CIF_DECLARE_INTERFACE(OclGenBinary, "OCL_GEN_BIN")
 
 // Default OCL GEN binary interface works only as 1:1 version checker,
 // but can be easily used for declaring backwards compatibility as well
-CIF_DEFINE_INTERFACE_VER(OclGenBinary, iOpenCL::CURRENT_ICBE_VERSION){
-  CIF_INHERIT_CONSTRUCTOR();
-};
+CIF_DEFINE_INTERFACE_VER(OclGenBinary, iOpenCL::CURRENT_ICBE_VERSION) { CIF_INHERIT_CONSTRUCTOR(); };
 
 CIF_GENERATE_VERSIONS_LIST_WITH_BASE(OclGenBinary, 1000);
 
@@ -37,6 +35,6 @@ CIF_MARK_LATEST_VERSION(OclGenBinaryLatest, OclGenBinary);
 using OclGenBinaryTagOCL = OclGenBinaryLatest; // Note : can tag with different version for
                                                //        transition periods
 
-}
+} // namespace IGC
 
 #include "cif/macros/disable.h"
