@@ -26,31 +26,25 @@ char ResourceLoopAnalysis::ID = 0;
 #define PASS_DESCRIPTION "Analyze the begin and end of a resource loop"
 #define PASS_CFG_ONLY false
 #define PASS_ANALYSIS true
-IGC_INITIALIZE_PASS_BEGIN(ResourceLoopAnalysis, PASS_FLAG, PASS_DESCRIPTION,
-                          PASS_CFG_ONLY, PASS_ANALYSIS)
+IGC_INITIALIZE_PASS_BEGIN(ResourceLoopAnalysis, PASS_FLAG, PASS_DESCRIPTION, PASS_CFG_ONLY, PASS_ANALYSIS)
 IGC_INITIALIZE_PASS_DEPENDENCY(WIAnalysis)
 IGC_INITIALIZE_PASS_DEPENDENCY(CodeGenContextWrapper)
-IGC_INITIALIZE_PASS_END(ResourceLoopAnalysis, PASS_FLAG, PASS_DESCRIPTION,
-                        PASS_CFG_ONLY, PASS_ANALYSIS)
+IGC_INITIALIZE_PASS_END(ResourceLoopAnalysis, PASS_FLAG, PASS_DESCRIPTION, PASS_CFG_ONLY, PASS_ANALYSIS)
 #undef PASS_FLAG
 #undef PASS_DESCRIPTION
 #undef PASS_CFG_ONLY
 #undef PASS_ANALYSIS
 
-llvm::FunctionPass *IGC::createResourceLoopAnalysisPass() {
-  return new ResourceLoopAnalysis;
-}
+llvm::FunctionPass *IGC::createResourceLoopAnalysisPass() { return new ResourceLoopAnalysis; }
 
 ResourceLoopAnalysis::ResourceLoopAnalysis() : FunctionPass(ID) {
   initializeResourceLoopAnalysisPass(*PassRegistry::getPassRegistry());
 }
 
 static bool ValueOnlyUsedByEEI(Value *V) {
-  for (Value::user_iterator UI = V->user_begin(), UE = V->user_end(); UI != UE;
-       ++UI) {
+  for (Value::user_iterator UI = V->user_begin(), UE = V->user_end(); UI != UE; ++UI) {
     ExtractElementInst *EEI = dyn_cast<ExtractElementInst>(*UI);
-    if (!EEI || (EEI->getOperand(0) != V) ||
-        !isa<ConstantInt>(EEI->getOperand(1))) {
+    if (!EEI || (EEI->getOperand(0) != V) || !isa<ConstantInt>(EEI->getOperand(1))) {
       return false;
     }
   }
@@ -61,8 +55,7 @@ bool ResourceLoopAnalysis::runOnFunction(Function &F) {
   auto WI = &(getAnalysis<WIAnalysis>());
   CTX = getAnalysis<CodeGenContextWrapper>().getCodeGenContext();
 
-  if (!IGC_IS_FLAG_ENABLED(FuseResourceLoop) ||
-      CTX->platform.GetPlatformFamily() < IGFX_XE_HPG_CORE) {
+  if (!IGC_IS_FLAG_ENABLED(FuseResourceLoop) || CTX->platform.GetPlatformFamily() < IGFX_XE_HPG_CORE) {
     return true;
   }
   for (Function::iterator BI = F.begin(), BE = F.end(); BI != BE; ++BI) {
@@ -70,8 +63,7 @@ bool ResourceLoopAnalysis::runOnFunction(Function &F) {
     // give every instruction a seq-no in order to check the location of uses
     std::map<Instruction *, unsigned> InstOrder;
     unsigned SeqNo = 0;
-    for (BasicBlock::iterator II = BB->begin(), EI = BB->end(); II != EI;
-         ++II) {
+    for (BasicBlock::iterator II = BB->begin(), EI = BB->end(); II != EI; ++II) {
       Instruction *I = &*II;
       InstOrder[I] = SeqNo++;
     }
@@ -82,8 +74,7 @@ bool ResourceLoopAnalysis::runOnFunction(Function &F) {
     auto prevMemIter = BB->end();   // last memory-inst in the loop
     SmallPtrSet<Value *, 8> DefSet; // all memory-inst in the loop
     SmallPtrSet<Value *, 8> DefOnly4EEI;
-    for (BasicBlock::iterator II = BB->begin(), EI = BB->end(); II != EI;
-         ++II) {
+    for (BasicBlock::iterator II = BB->begin(), EI = BB->end(); II != EI; ++II) {
       Instruction *I = &*II;
       unsigned curOpTy = 0;
       Value *curRes = nullptr;
@@ -143,8 +134,7 @@ bool ResourceLoopAnalysis::runOnFunction(Function &F) {
       if ((curRes || curSamp) && curOpTy) {
         // this is a lane-varying-resource-access
         bool LoopEnd = HasDeps;
-        if (!LoopEnd && curOpTy == loopOpTy && curRes == loopRes &&
-            curSamp == loopSamp) {
+        if (!LoopEnd && curOpTy == loopOpTy && curRes == loopRes && curSamp == loopSamp) {
           // need to check ALU instruction in between
           // all those instructions should only be used
           // inside the loop
@@ -157,14 +147,12 @@ bool ResourceLoopAnalysis::runOnFunction(Function &F) {
               ++III;
               continue;
             }
-            for (auto UI = defInst->user_begin(), UE = defInst->user_end();
-                 !LoopEnd && UI != UE; ++UI) {
+            for (auto UI = defInst->user_begin(), UE = defInst->user_end(); !LoopEnd && UI != UE; ++UI) {
               // Determine the block of the use.
               Instruction *useInst = cast<Instruction>(*UI);
               if (InstOrder.find(useInst) == InstOrder.end())
                 LoopEnd = true;
-              else if (InstOrder[useInst] > InstOrder[I] ||
-                       InstOrder[useInst] <= InstOrder[defInst])
+              else if (InstOrder[useInst] > InstOrder[I] || InstOrder[useInst] <= InstOrder[defInst])
                 LoopEnd = true;
             }
             ++III;
@@ -235,14 +223,12 @@ bool ResourceLoopAnalysis::runOnFunction(Function &F) {
                     .Pass("ResourceLoop")
                     .PostFix(F.getName().str())
                     .Extension("txt");
-    printResourceLoops(
-        Debug::Dump(name, Debug::DumpType::DBG_MSG_TEXT).stream(), &F);
+    printResourceLoops(Debug::Dump(name, Debug::DumpType::DBG_MSG_TEXT).stream(), &F);
   }
   return false;
 }
 
-void ResourceLoopAnalysis::printResourceLoops(raw_ostream &OS,
-                                              Function *F) const {
+void ResourceLoopAnalysis::printResourceLoops(raw_ostream &OS, Function *F) const {
   if (F) {
     // All instructions
     for (auto II = inst_begin(F), IE = inst_end(F); II != IE; ++II) {
