@@ -19,21 +19,21 @@ SPDX-License-Identifier: MIT
 #endif
 
 namespace IGCLLD {
-    namespace elf {
-        inline bool link(llvm::ArrayRef<const char *> Args, bool CanExitEarly,
-                         llvm::raw_ostream &stdoutOS, llvm::raw_ostream &stderrOS) {
+namespace elf {
+inline bool link(llvm::ArrayRef<const char *> Args, bool CanExitEarly, llvm::raw_ostream &stdoutOS,
+                 llvm::raw_ostream &stderrOS) {
 #if LLVM_VERSION_MAJOR >= 14
-            bool r = lld::elf::link(Args, stdoutOS, stderrOS, CanExitEarly, false);
-            lld::CommonLinkerContext::destroy();
-            return r;
+  bool r = lld::elf::link(Args, stdoutOS, stderrOS, CanExitEarly, false);
+  lld::CommonLinkerContext::destroy();
+  return r;
 #elif LLVM_VERSION_MAJOR >= 10
-            return lld::elf::link(Args, CanExitEarly, stdoutOS, stderrOS);
+  return lld::elf::link(Args, CanExitEarly, stdoutOS, stderrOS);
 #else
-            (void)stdoutOS;
-             return lld::elf::link(Args, CanExitEarly, stderrOS);
+  (void)stdoutOS;
+  return lld::elf::link(Args, CanExitEarly, stderrOS);
 #endif
-        }
-    } // namespace elf
+}
+} // namespace elf
 } // namespace IGCLLD
 
 #endif // IGCLLVM_LLD_COMMON_DRIVER_H
